Changelog
=========

Version 1.2.4
-------------
* Add "Content-Type" header (Arthur Furlan)

Version 1.2.3
-------------
* Fix KeyError bug in auto-scaling code (Ben Belchak)

Version 1.2.2
-------------
* Fix comparative bar on bullet graphs (Rod Begbie)

Version 1.2.1
-------------
* Fix unicode handling (Éric St-Jean)

Version 1.2.0
-------------
* Added *bullet* widget decorator contributed by Hedley Roos.

Version 1.1.0
-------------
* Added *funnel* widget decorator contributed by Simon de Haan.

Version 1.0.0
-------------
* No changes from 0.2.1.

Version 0.2.1
-------------
* Fixed API key detection.

Version 0.2.0
-------------
* Renamed widget decorators.

Version 0.1.0
-------------
* First release, split off from django-analytical_.

.. _django-analytical: http://pypi.python.org/pypi/django-analytical
